from demographics.data.us.race import data as us_race_data
from demographics.data.us.gender import data as us_gender_data
from collections import namedtuple 

Demographic = namedtuple('Demographic', ('first', 'last', 'popularity', 'male', 'female', 'white', 'black', 'hispanic', 'aian', 'api', 'multi', 'raw'))

USRaw = namedtuple('USRaw', ('gender', 'race'))

def us_demographics(firstname, lastname):
    firstname = firstname.upper()
    lastname = lastname.upper()

    gender_data = us_gender_data[firstname]
    race_data = us_race_data[lastname]
    
    p = (gender_data.m + gender_data.f) * race_data.rate
    
    return Demographic(firstname.lower(), 
                       lastname.lower(),
                       p,
                       gender_data.m / (gender_data.m + gender_data.f),
                       gender_data.f / (gender_data.m + gender_data.f),
                       race_data.white,
                       race_data.black, 
                       race_data.hispanic,
                       race_data.aian,
                       race_data.api,
                       race_data.multi,
                       USRaw(gender_data, race_data))


def us_demographics_as_dict(firstname, lastname):
    d = us_demographics(firstname, lastname)
    return dict(first=d.first,
                last=d.last,
                popularity=d.popularity,
                male=d.male,
                female=d.female,
                white=d.white,
                black=d.black,
                hispanic=d.hispanic,
                aian=d.aian,
                api=d.api,
                multi=d.multi,
                raw=dict(
                    gender=d.raw.gender,
                    raced=d.raw.race)
            )
             



#!/usr/bin/env python

"""Python Demographics
===================

Generate gender and race estimates from name.  Based on 1990 Census
given name gender compilation [1] and the 2000 census surname race
compilation [2].

[1] http://www.census.gov/genealogy/www/data/1990surnames/names_files.html
[2] https://www.census.gov/genealogy/www/data/2000surnames/

"""

from setuptools import setup

setup(
    name='demographics',
    version='0.0.0',
    author='Adam DePrince',
    author_email='adeprince@nypublicradio.org',
    description='Estimate user\'s demographics from their name or email address.',
    url="",
    long_description=__doc__,
    py_modules=[
        'demographics/__init__',
        'demographics/data/__init__',
        'demographics/data/us/__init__',
        'demographics/data/us/race',
        'demographics/data/us/gender',
        ],
    packages=['demographics',],
    zip_safe=True,
    license='MIT',
    include_package_data=False,
    classifiers=[],
    scripts=[],
    install_requires=[
        ]
    )
